/* The demo application for the late join service, Version 0.1 alpha.
 *  
 * Copyright (C) 2000 Juergen Vogel, Martin Mauve
 * University of Mannheim / Germany
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Juergen Vogel
 * Martin Mauve
 *
 * e-mail:
 * {vogel,mauve}@informatik.uni-mannheim.de
 * 
 * paper mail:
 *
 * Juergen Vogel
 * Martin Mauve
 * University of Mannheim
 * Lehrstuhl Praktische Informatik IV
 * L15, 16
 * 68131 Mannheim
 * Germany
 */

package rtpi.demoLatejoin;

import java.io.ByteArrayOutputStream;
import java.io.DataOutputStream;

class Subcomponent {
    private long id;
    private String name;
    private byte[] nameBytes;
    private byte state;
    private boolean active;
    private ComponentView view;
    private Application app;

    private boolean stateReceived = false;

    private int eventSequenceNumber = -1;
    private int stateSequenceNumber = -1;
    private int stateQuerySequenceNumber = -1;
    private int ljStateSequenceNumber = -1;

    Subcomponent(Application a, String n, long i) {
	app = a;
	name = n;
	ByteArrayOutputStream bos = new ByteArrayOutputStream();
	DataOutputStream dos = new DataOutputStream(bos);
	try {
	    dos.writeUTF(name);
	    dos.flush();
	    bos.flush();
	    nameBytes=bos.toByteArray();
	    dos.close();
	    bos.close();
	} catch (Exception ex) {
	    System.err.println("Component: Could not flush subcomponent name!");
	    System.exit(0);
	}
	state = 0;
	id = i;
	active = true;
	view = new ComponentView(this);
    }

    void setState(byte s) {
	state = s;
	view.update();
    }

    byte getState() {
	return state;
    }

    String getName() {
	return name;
    }

    byte[] getNameBytes() {
	return nameBytes;
    }

    void increment() {
	state++;
	app.sendIncrEvent(id);
    }

    long getID() {
	return id;
    }

    ComponentView getView() {
	return view;
    }

    void setActive(boolean a) {
	active = a;

	if (active)
	    app.activateSubcomponent(id);
	else
	    app.deactivateSubcomponent(id);
    }

    boolean getActive() {
	return active;
    }

    public boolean equals(Object obj) {
	return (id==(((Subcomponent)obj).getID()));
    }

    boolean getStateReceived() {
	return stateReceived;
    }

    void setStateReceived() {
	stateReceived = true;
    }

    int getNextStateQuerySequenceNumber() {
	stateQuerySequenceNumber++;
	
	if (stateQuerySequenceNumber == 65536) 
	    stateQuerySequenceNumber=0;
	
	return stateQuerySequenceNumber;
    }

    int getNextStateSequenceNumber() {
	stateSequenceNumber++;
	
	if (stateSequenceNumber == 65536) 
	    stateSequenceNumber=0;
	
	return stateSequenceNumber;
    }

    int getNextEventSequenceNumber() {
	eventSequenceNumber++;
	
	if (eventSequenceNumber == 65536) 
	    eventSequenceNumber=0;
	
	return eventSequenceNumber;
    }

    int getNextLJStateSequenceNumber() {
	ljStateSequenceNumber++;
	
	if (ljStateSequenceNumber == 65536) 
	    ljStateSequenceNumber=0;
	
	return ljStateSequenceNumber;
    }

}


