/* The Java RTP/I library, Version 0.1 alpha.
 *  
 * This library provides the functionality of RTP/I as it is specified in
 * Internet Draft draft-mauve-rtpi-00.txt. 
 *
 * Copyright (C) 2000 Martin Mauve
 * University of Mannheim / Germany
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Martin Mauve
 *
 * e-mail:
 * mauve@informatik.uni-mannheim.de
 * 
 * paper mail:
 * Martin Mauve
 * University of Mannheim
 * Lehrstuhl Praktische Informatik IV
 * L15, 16
 * 68131 Mannheim
 * Germany
 */

package rtpi.packets;

public class SubcomponentReportInfo {
    
    /**
     * Instances of this class represents the information that
     * is contained in a SUBREP packet about a single subcomonent.
     *
     * @author Martin Mauve
     */

    private long subcomponentID;
    private byte[] applicationLevelName;
    private int active; 

    /**
     * This creates a new instance.
     *
     * @param si The ID of the subcomponent.
     * @param a The active bit (1=active, 0= inactive)
     * @param name The application level name (may be null if application level names are not used)
     */

    public SubcomponentReportInfo(long si, int a, byte[] name) {
	subcomponentID=si;
	active=a;
	applicationLevelName=name;
    }

    /**
     * This returns the ID of the subcomponent.
     *
     * @return The subcomponent ID
     */

    public long getSubcomponentID() {
	return subcomponentID;
    }

    /**
     * This returns the active bit for this reported subcomponent.
     *
     * @return The active bit.
     */

    public int getActive() {
	return active;
    }

    /**
     * This returns the application level name of this reported subcomponent.
     *
     * @return The application level name (may be null if application level names are not used).
     */

    public byte[] getApplicationLevelName() {
	return applicationLevelName;
    }

    /**
     * This converts the information about this report into a String.
     *
     * @return This object as a string.
     */

    public String toString() {
	String returnValue="ID: "+subcomponentID+" active: "+active;
	if (applicationLevelName==null) {
	    returnValue+=" no application level name\n";
	} else {
	    returnValue+=" "+new String(applicationLevelName)+"\n";
	}
	return returnValue;
    }
    
}
		 
