/* The Java RTP/I library, Version 0.1 alpha.
 *  
 * This library provides the functionality of RTP/I as it is specified in
 * Internet Draft draft-mauve-rtpi-00.txt. 
 *
 * Copyright (C) 2000 Martin Mauve
 * University of Mannheim / Germany
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Martin Mauve
 *
 * e-mail:
 * mauve@informatik.uni-mannheim.de
 * 
 * paper mail:
 * Martin Mauve
 * University of Mannheim
 * Lehrstuhl Praktische Informatik IV
 * L15, 16
 * 68131 Mannheim
 * Germany
 */

package rtpi.reliability;

import java.util.LinkedList;

/**
 * This interface is to be implemented by a class that whishes to
 * be notified about ADUs received by a reliability service.
 *
 * @author Martin Mauve
 */

public interface ReliableRecipient {


    /**
     * An ADU has been completely received.
     *
     * @param packets The packets belonging to the ADU. They MUST be of the
     *                type RtpiDataPacket.
     */

    void receiveRtpiAdu(LinkedList packets);

    /**
     * This method is invoked when the reliability service has detected
     * a lost packet and was not instructed to repair the loss of this
     * packet.
     *
     * @param participantID The ID of the sender of the lost ADU.
     * @param subID The ID of the affected subcomponent.
     * @param type The type (STATE, EVENT, etc.) of the lost ADU.
     * @param sequenceNumber The sequence number of the lost ADU.
     * @param timestamp A timestamp that is greater or equal to the timestamp
     *                  of the lost ADU.
     */

    void rtpiAduLost(int participantID, long subID, int type, int sequenceNumber, int timestamp);

    /**
     * This method is invoked when the reliability service has detected
     * a lost packet and was instructed to repair the loss but was unable 
     * to do so.
     *
     * @param participantID The ID of the sender of the lost ADU.
     * @param subID The ID of the affected subcomponent.
     * @param type The type (STATE, EVENT, etc.) of the lost ADU.
     * @param sequenceNumber The sequence number of the lost ADU.
     * @param timestamp A timestamp that is greater or equal to the timestamp
     *                  of the lost ADU.
     */

    void rtpiCouldNotRecover(int participantID, long subID, int type, int sequenceNumber, int timestamp);

    /**
     * This method is called when the reliability service used for RTP/I has encountered a fatal error.
     */

    void connectionClosed();

}
