/* The Java RTP/I latejoin service, Version 0.1 alpha.
 *  
 * This library provides the functionality of a generic RTP/I latejoin service.
 *
 * Copyright (C) 2000 Juergen Vogel, Martin Mauve
 * University of Mannheim / Germany
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Juergen Vogel
 * Martin Mauve
 *
 * e-mail:
 * {vogel,mauve}@informatik.uni-mannheim.de
 * 
 * paper mail:
 *
 * Juergen Vogel
 * Martin Mauve
 * University of Mannheim
 * Lehrstuhl Praktische Informatik IV
 * L15, 16
 * 68131 Mannheim
 * Germany
 */


package rtpi.services.latejoin;

import rtpi.Rtpi;
import rtpi.RtpiRecipient;
import rtpi.RtpiState;

/**
 * This interface needs to be implemented by the application that employs the late join service.
 * All messages of the base RTP/I session are forwarded unmodified and immediately to the 
 * application.
 * 
 * @author Juergen Vogel
 * @author Martin Mauve
 */

public interface LateJoinRecipient extends RtpiRecipient {

    /**
     * This method is called when the late join service discoveres a new subcomponent by
     * receivin a RTCP/I SUBREP packet. The application is supposed to decide on the late
     * join policy for that subcomponent can then call setPolicy on the late join service.
     *
     * @param subcomponentID The subcomponent ID of the subcomponent that has been discovered.
     */ 

    void lateJoinAskForPolicy(long subcomponentID);

    /**
     * This method is called when the late join service is unable to get the state of a subcomponent.
     * This can happen when the subcomponent is no longer available at the time the late join service
     * requests for the transmission of the subcomponent's state. It can also happen if no application
     * is willing to extract the state of the subcomponent.
     *
     * @param subcomponentID The subcomponent ID of the subcomponent.
     */ 

    void lateJoinFailed(long subcomponentID);

    /**
     * This method is called when the late join service needs the state of a subcomponent, in order
     * to help another late join service instance with the late join. If the join policy LateJoin.APPLICATION
     * has been chosen then this will only be called when the application has claimed the responsibility of
     * the subcomponent. If the join policy LateJoin.AUTOMATIC has been chosen, then the application may
     * be selected to extract the state for late join purposes when it has received the state of that subcomponent.
     * An application may ignore a lateJoinGetState message. However, the more applications ignore this message,
     * the longer will it take to get the state for the latecomer. If a very large percentage of participants
     * ignores this message, then the late join for that subcomponent may fail. If only one participant is able
     * to reply to a state query then the join policy LateJoin.Application should be chosen.
     * IF the application is able and willing to provide the state of the subcomponent, then it must tell the late
     * join service that it will deliver the state by calling LateJoin.acknowledgeTransmitState. Then it may take
     * some time to extract the state and finally it should deliver the state to the late join service by using
     * LateJoin.transmitState.
     *
     * @param subcomponentID The subcomponent ID of the subcomponent.
     */
 
    void lateJoinGetState(long subcomponentID);

    /**
     * This method is called when the late join service has successfully retrieved the state of a subcomponent.
     *
     * @param r The RTP/I instance over which the state has been transmitted (this should be the late join RTP/I session)
     * @param state 
     */

    void lateJoinReceiveState(Rtpi r, RtpiState state);

    /**
     * This method is invoked when the late join has died unexpenctandly.
     */

    void lateJoinTerminated();
}
