/* The Java RTP/I latejoin service, Version 0.1 alpha.
 *  
 * This library provides the functionality of a generic RTP/I latejoin service.
 *
 * Copyright (C) 2000 Juergen Vogel, Martin Mauve
 * University of Mannheim / Germany
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Juergen Vogel
 * Martin Mauve
 *
 * e-mail:
 * {vogel,mauve}@informatik.uni-mannheim.de
 * 
 * paper mail:
 *
 * Juergen Vogel
 * Martin Mauve
 * University of Mannheim
 * Lehrstuhl Praktische Informatik IV
 * L15, 16
 * 68131 Mannheim
 * Germany
 */

package rtpi.services.latejoin;

class Subcomponent {
    static final int SUBCOMP_DISCOVERED   = 0;
    static final int POLICY_SET           = 1;
    static final int REQUESTED            = 3;  // own or foreign request
    static final int COMPLETE             = 4;
    static final int FAILED               = 5;
    static final int NOT_INTERESTED       = 6;

    private int state;
    private boolean registered;
    private int policy;
    private long lastTimeSeen;
    private boolean acknowledged;

    Subcomponent() {
	policy = LateJoin.NO_POLICY_YET;
	state  = SUBCOMP_DISCOVERED;
	registered = false;
	lastTimeSeen = -1;
	acknowledged = false;
    }

    void setState(int s) {
	state = s;
    }

    int getState() {
	return state;
    }

    void setPolicy(int p) {
	policy = p;
    }

    int getPolicy() {
	return policy;
    }

    void setRegistered(boolean r) {
	registered = r;
    }

    boolean getRegistered() {
	return registered;
    }

    void setLastTimeSeenNow() {
	lastTimeSeen = System.currentTimeMillis();
    }

    long getLastTimeSeen() {
	return lastTimeSeen;
    }

    void setAcknowledged(boolean a) {
	acknowledged = a;
    }

    boolean getAcknowledged() {
	return acknowledged;
    }
}
