/* The Java RTP/I latejoin service, Version 0.1 alpha.
 *  
 * This library provides the functionality of a generic RTP/I latejoin service.
 *
 * Copyright (C) 2000 Juergen Vogel, Martin Mauve
 * University of Mannheim / Germany
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Juergen Vogel
 * Martin Mauve
 *
 * e-mail:
 * {vogel,mauve}@informatik.uni-mannheim.de
 * 
 * paper mail:
 *
 * Juergen Vogel
 * Martin Mauve
 * University of Mannheim
 * Lehrstuhl Praktische Informatik IV
 * L15, 16
 * 68131 Mannheim
 * Germany
 */

package rtpi.services.latejoin;

import java.util.*;

class TimerObject {
    public final static int SERVER_TIMEOUT = 0;
    public final static int STATE_QUERY    = 1;
    public final static int STATE_REPLY    = 2;
    public final static int NET_QUERY      = 3;
    public final static int CLIENT_TIMEOUT = 4;

    public long startingTime;
    public long runningTime;
    public int type;
    public ExecuteTimer callback;

    public TimerObject(long rtime, int t, ExecuteTimer c) {
	startingTime = (new Date()).getTime();
	runningTime  = rtime;
	type         = t;
	callback     = c;
    }

    public long computeSleepingTime() {
	long actualTime = (new Date()).getTime();
	long sleepingTime = runningTime - actualTime + startingTime;

	if (sleepingTime < 20)
	    return 20;
	else
	    return sleepingTime;
    }

    public long computeEndingTime() {
	return (startingTime + runningTime);
    }

    public boolean greaterThan(TimerObject timer) {
	return (computeEndingTime() > timer.computeEndingTime());
    }

    public void print() {
	System.out.print("(" + startingTime + "," + runningTime + "," + type + ")");
    }
}
