/* The Java RTP/I library, Version 0.1 alpha.
 *  
 * This library provides the functionality of RTP/I as it is specified in
 * Internet Draft draft-mauve-rtpi-00.txt. 
 *
 * Copyright (C) 2000 Martin Mauve
 * University of Mannheim / Germany
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Martin Mauve
 *
 * e-mail:
 * mauve@informatik.uni-mannheim.de
 * 
 * paper mail:
 * Martin Mauve
 * University of Mannheim
 * Lehrstuhl Praktische Informatik IV
 * L15, 16
 * 68131 Mannheim
 * Germany
 */

package rtpi.transport;

import java.net.InetAddress;

/**
 * This is an abstraction of a transport layer packet.
 */

public class TransportPacket {

    int length;
    byte[] data;
    InetAddress senderAddress;
    int senderPort;

    /** 
     * This constuctor is used by a transport instance, to encapsulate a 
     * data received from the net. 
     *
     * @param l Length of the data contained in the packet.
     * @param d Data contained in the packet. Note that d.length might
     *          be larger than the number of bytes received from the net.
     * @param add The address of the sender.
     * @param p The port of the sender.
     */

    public TransportPacket(int l, byte[] d, InetAddress add, int p) {
	length = l;
	data = d;
	senderAddress = add;
	senderPort = p;
    }


    /**
     * This constructer is used to construct a packet that should be send
     * over the net.
     *
     * @param l Length of the data contained in the packet.
     * @param d Data contained in the packet. Note that d.length might
     *          be larger than the number of bytes received from the net.
     */

    public TransportPacket(int l, byte[] d) {
	length = l;
	data = d;
    }


    /**
     * This returns the length of the data (in Bytes) that is included
     * in this packet.
     *
     * @return The length of the data.
     */
    
    public int getLength() {
	return length;
    }
    

    /**
     * This sets the length of the data (in Bytes) that is included
     * in this packet. Note that the length must be smaller than
     * the length of the data array.
     *
     * @param len The length of the data.
     */

    public void setLength(int len) {
	if (len > data.length) {
	    System.err.println("TransportPacket: Tried to set packet lengh too high - ignored!");
	    return;
	}

	length=len;
    }


    /**
     * Get the data included in this packet.
     *
     * @return The data.
     */

    public byte[] getData() {
	return data;
    }

    /** 
     * Get the port of the sender.
     *
     * @return The sender port.
     */

    public int getSenderPort() {
	return senderPort;
    }


    /**
     * Get the address of the sender.
     *
     * @return The sender network address.
     */

    public InetAddress getSenderAddress() {
	return senderAddress;
    }

}
						   
