/* The Java RTP/I library, Version 0.1 alpha.
 *  
 * This library provides the functionality of RTP/I as it is specified in
 * Internet Draft draft-mauve-rtpi-00.txt. 
 *
 * Copyright (C) 2000 Martin Mauve
 * University of Mannheim / Germany
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Martin Mauve
 *
 * e-mail:
 * mauve@informatik.uni-mannheim.de
 * 
 * paper mail:
 * Martin Mauve
 * University of Mannheim
 * Lehrstuhl Praktische Informatik IV
 * L15, 16
 * 68131 Mannheim
 * Germany
 */

package rtpi.transport;

/**
 * This is the interface which needs to be implemented by a class that
 * wants to be the recipient of transport packets.
 *
 * @author Martin Mauve
 */

public interface TransportRecipient {

    /**
     * This method is called by the transport instance in order to
     * deliver a transport packet.
     *
     * @param packet The transport packet.
     */

    void receiveTransportPacket(TransportPacket packet);

    /**
     * This method is called by the transport instance in case
     * the connection to the server breaks and packet can not be
     * sent or received anymore.
     * The suggested behaviour is to call the method leaveGroup()
     * of the transport instance and possibly trying to rejoin the
     * group by calling joinGroup().
     *
     * @param packet The transport packet.
     */    

    void connectionClosed();

}
