/* The Java RTP/I library, Version 0.1 alpha.
 *  
 * This library provides the functionality of RTP/I as it is specified in
 * Internet Draft draft-mauve-rtpi-00.txt. 
 *
 * Copyright (C) 2000 Martin Mauve
 * University of Mannheim / Germany
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Martin Mauve
 *
 * e-mail:
 * mauve@informatik.uni-mannheim.de
 * 
 * paper mail:
 * Martin Mauve
 * University of Mannheim
 * Lehrstuhl Praktische Informatik IV
 * L15, 16
 * 68131 Mannheim
 * Germany
 */

package rtpi.transport.ipmc;

import rtpi.transport.Transport;
import rtpi.transport.TransportRecipient;
import rtpi.transport.TransportPacket;

import java.net.*;
import java.io.IOException;

//import java.util.Random;

class IPMCTransportListener extends Thread {

    IPMCTransport sender;
    MulticastSocket socket;

    TransportRecipient recipient;

    boolean continueWork=true;

    InetAddress localHost;

    //Random generator = new Random();

    
    IPMCTransportListener(TransportRecipient rec, MulticastSocket soc, IPMCTransport trans) {
	sender=trans;
	socket=soc;
	recipient=rec;
	try {
	    localHost=InetAddress.getLocalHost();
	} catch (UnknownHostException ex) {
	    System.err.println("IPMCTransportListener: Can't get local host address!");
	}
    }

    public void run() {
	while (continueWork) {
	    byte[] buf = new byte[sender.getTransportPayloadSize()];
	    DatagramPacket packet =new DatagramPacket(buf, buf.length);
	    try {
		socket.receive(packet);
	    } catch (IOException ex) {
		if (!continueWork) {
		    buf=null;
		    packet=null;
		} else {
		    continueWork=false;
		    System.err.println("IPMCTransportListener: Connection broken!");
		}
	    }

	    // if (generator.nextInt(5)==1) continue;

	    if (continueWork) sender.updateReceivedRate(packet.getLength());

	    if ((packet!=null) && !localHost.equals(packet.getAddress())) {
		TransportPacket tPacket = new TransportPacket(packet.getLength(),buf,
							      packet.getAddress(), packet.getPort());
		recipient.receiveTransportPacket(tPacket);
	    }
	}
    }

    void leaveGroup() {
	continueWork=false;
    }

}
	    

	    
		
